import { ICellRendererComp, ICellRendererParams } from '@ag-grid-community/core';
import { FoundationElement } from '@microsoft/fast-foundation';
/**
 * Parameters for the {@link @genesislcap/grid-pro#GridPro} action renderer.
 * @remarks For single action button scenarios.
 * @public
 */
export type ActionRendererParams = {
    /**
     * Callback function triggered when the action button is clicked.
     * @param rowData - The data associated with the row.
     */
    actionClick?: (rowData: any) => void;
    /**
     * The name or label of the action button.
     */
    actionName?: string;
    /**
     * The appearance style of the action button.
     * @remarks This is a {@link @microsoft/fast-foundation#Button.appearance | Button appearance} value. Defaults to `neutral`. May have other values depending on the design system.
     */
    appearance?: string;
    /**
     * The data-test-id attribute value to be used for E2E testing.
     */
    dataTestId?: string;
    /**
     * Function to determine whether the action button should be disabled for a specific row.
     * @param rowData - The data associated with the row.
     * @returns A boolean indicating whether the button should be disabled.
     */
    isDisabled?: (rowData: any) => boolean;
    /**
     * A unique field name used to identify the action button used for E2E testing, so that the data-testid attribute value can be unique.
     */
    uniqueFieldName?: string;
    contentTemplate?: string;
};
/**
 * The AG Action Renderer element.
 * @public
 * @tagname %%prefix%%-grid-pro-action-renderer
 */
export declare class ActionRenderer extends FoundationElement implements ICellRendererComp {
    params: ICellRendererParams & ActionRendererParams;
    pendingAction: boolean;
    init(params: ICellRendererParams & ActionRendererParams): void;
    getGui(): HTMLElement;
    refresh(params: ICellRendererParams): boolean;
    isDisabled(data: any): boolean;
    clickHandler(): Promise<void>;
    get dataTestId(): string;
}
/**
 * The base height multiplier for the action renderer.
 * @remarks Results in `--action-height-multiplier`. This is a DesignToken {@link https://www.fast.design/docs/design-systems/design-tokens/#what-is-a-design-token} value. Defaults to `0.6px`. May have other values depending on the design system or can be set to a different value.
 * @public
 */
export declare const actionHeightMultiplier: import("@microsoft/fast-foundation").CSSDesignToken<string>;
/**
 * The AG Action Renderer Styles.
 * @public
 */
export declare const agActionRendererStyles: import("@microsoft/fast-element").ElementStyles;
/**
 * A function that returns a Foundation Action Renderer for configuring the component with a DesignSystem.
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-grid-pro-action-renderer\>
 */
export declare const foundationGridProActionRenderer: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    styles: import("@microsoft/fast-element").ElementStyles;
    template: import("@microsoft/fast-element").ViewTemplate<ActionRenderer, any>;
}>) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    styles: import("@microsoft/fast-element").ElementStyles;
    template: import("@microsoft/fast-element").ViewTemplate<ActionRenderer, any>;
}, typeof ActionRenderer>;
//# sourceMappingURL=action.renderer.d.ts.map